@@ -15,9 +15,10 @@ async def connection_handler(websocket, path):
   client_ip = websocket.remote_address[0]
   if client_ip == "127.0.0.1" and "X-Real-IP" in websocket.request_headers:
     client_ip = websocket.request_headers["X-Real-IP"]
+  origin = websocket.request_headers.get("Origin")
 
   conn_id = "".join(random.choices("1234567890abcdef", k=8))
-  logging.info(f"({conn_id}) incoming connection on {path} from {client_ip}")
+  logging.info(f"({conn_id}) incoming connection on {path} from {client_ip} (origin: {origin})")
   ratelimit.inc_client_attr(client_ip, "streams")
 
   if path.endswith("/"):
@@ -60,18 +61,15 @@ async def static_handler(path, request_headers):
 
 async def main(args):
   global static_path
-  logging.info(f"running wisp-server-python v{wisp.version}")
 
   if args.static:
     static_path = pathlib.Path(args.static).resolve()
     request_handler = static_handler
     mimetypes.init()
-    logging.info(f"serving static files from {static_path}")
   else:
     request_handler = None
   
   if args.limits:
-    logging.info("enabled rate limits")
     ratelimit.enabled = True
     ratelimit.connections_limit = int(args.connections)
     ratelimit.bandwidth_limit = float(args.bandwidth)
@@ -81,10 +79,10 @@ async def main(args):
   net.block_private = not args.allow_private
       
   limit_task = asyncio.create_task(ratelimit.reset_limits_timer())
-  logging.info(f"listening on {args.host}:{args.port}")
-
   ws_logger = logging.getLogger("websockets")
   ws_logger.setLevel(logging.WARN)
 
-  async with serve(connection_handler, args.host, int(args.port), process_request=request_handler, compression=None):
+  reuse_port = net.reuse_port_supported()
+
+  async with serve(connection_handler, args.host, int(args.port), reuse_port=reuse_port, process_request=request_handler, compression=None):
     await asyncio.Future()
\ No newline at end of file
